@@ -28,12 +28,12 @@
 
 This AWS Solutions Construct implements an Amazon API Gateway connected to an Amazon SQS queue pattern.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
 ```javascript
-const { ApiGatewayToSqs } = require('@aws-solutions-constructs/aws-apigateway-sqs');
+import { ApiGatewayToSqs, ApiGatewayToSqsProps } from "@aws-solutions-constructs/aws-apigateway-sqs";
 
-new ApiGatewayToSqs(stack, 'ApiGatewayToSqsPattern', {
+new ApiGatewayToSqs(this, 'ApiGatewayToSqsPattern', {
     apiGatewayProps: {},
     queueProps: {},
     deployDeadLetterQueue?: true,
@@ -120,8 +120,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -145,14 +145,14 @@ class ApiGatewayToSqs(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        allow_create_operation: typing.Optional[bool] = None,
-        allow_delete_operation: typing.Optional[bool] = None,
-        allow_read_operation: typing.Optional[bool] = None,
+        allow_create_operation: typing.Optional[builtins.bool] = None,
+        allow_delete_operation: typing.Optional[builtins.bool] = None,
+        allow_read_operation: typing.Optional[builtins.bool] = None,
         api_gateway_props: typing.Any = None,
-        create_request_template: typing.Optional[str] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
+        create_request_template: typing.Optional[builtins.str] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
@@ -188,32 +188,32 @@ class ApiGatewayToSqs(
 
         jsii.create(ApiGatewayToSqs, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return jsii.get(self, "apiGateway")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> aws_cdk.aws_iam.Role:
         return jsii.get(self, "apiGatewayCloudWatchRole")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return jsii.get(self, "apiGatewayLogGroup")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
         return jsii.get(self, "apiGatewayRole")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return jsii.get(self, "sqsQueue")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return jsii.get(self, "deadLetterQueue")
@@ -237,12 +237,12 @@ class ApiGatewayToSqsProps:
     def __init__(
         self,
         *,
-        allow_create_operation: typing.Optional[bool] = None,
-        allow_delete_operation: typing.Optional[bool] = None,
-        allow_read_operation: typing.Optional[bool] = None,
+        allow_create_operation: typing.Optional[builtins.bool] = None,
+        allow_delete_operation: typing.Optional[builtins.bool] = None,
+        allow_read_operation: typing.Optional[builtins.bool] = None,
         api_gateway_props: typing.Any = None,
-        create_request_template: typing.Optional[str] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
+        create_request_template: typing.Optional[builtins.str] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
@@ -261,7 +261,7 @@ class ApiGatewayToSqsProps:
         """
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if allow_create_operation is not None:
             self._values["allow_create_operation"] = allow_create_operation
         if allow_delete_operation is not None:
@@ -280,31 +280,34 @@ class ApiGatewayToSqsProps:
             self._values["queue_props"] = queue_props
 
     @builtins.property
-    def allow_create_operation(self) -> typing.Optional[bool]:
+    def allow_create_operation(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy an API Gateway Method for Create operations on the queue (i.e. sqs:SendMessage).
 
         default
         :default: - false
         """
-        return self._values.get("allow_create_operation")
+        result = self._values.get("allow_create_operation")
+        return result
 
     @builtins.property
-    def allow_delete_operation(self) -> typing.Optional[bool]:
+    def allow_delete_operation(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy an API Gateway Method for Delete operations on the queue (i.e. sqs:DeleteMessage).
 
         default
         :default: - false
         """
-        return self._values.get("allow_delete_operation")
+        result = self._values.get("allow_delete_operation")
+        return result
 
     @builtins.property
-    def allow_read_operation(self) -> typing.Optional[bool]:
+    def allow_read_operation(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy an API Gateway Method for Read operations on the queue (i.e. sqs:ReceiveMessage).
 
         default
         :default: - false
         """
-        return self._values.get("allow_read_operation")
+        result = self._values.get("allow_read_operation")
+        return result
 
     @builtins.property
     def api_gateway_props(self) -> typing.Any:
@@ -313,25 +316,28 @@ class ApiGatewayToSqsProps:
         default
         :default: - Default properties are used.
         """
-        return self._values.get("api_gateway_props")
+        result = self._values.get("api_gateway_props")
+        return result
 
     @builtins.property
-    def create_request_template(self) -> typing.Optional[str]:
+    def create_request_template(self) -> typing.Optional[builtins.str]:
         """API Gateway Request template for Create method, required if allowCreateOperation set to true.
 
         default
         :default: - None
         """
-        return self._values.get("create_request_template")
+        result = self._values.get("create_request_template")
+        return result
 
     @builtins.property
-    def deploy_dead_letter_queue(self) -> typing.Optional[bool]:
+    def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy a secondary queue to be used as a dead letter queue.
 
         default
         :default: - required field.
         """
-        return self._values.get("deploy_dead_letter_queue")
+        result = self._values.get("deploy_dead_letter_queue")
+        return result
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -340,7 +346,8 @@ class ApiGatewayToSqsProps:
         default
         :default: - required only if deployDeadLetterQueue = true.
         """
-        return self._values.get("max_receive_count")
+        result = self._values.get("max_receive_count")
+        return result
 
     @builtins.property
     def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -349,12 +356,13 @@ class ApiGatewayToSqsProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("queue_props")
+        result = self._values.get("queue_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
